function res =  polstar(n, R, r)
//-----------------------------------------------------------------------  
// function res =  polstar(n, R, r)
//
// function "polstar" generates an origin centered "star" 
//
// input:    n            the number of arms of the expected star
//           R            outer radius of the star,
//           r            inner radious of the star
//  
// output:   res          a  2 * (2*n) matrix with indices of the
//                        star as its elements    
//
//-----------------------------------------------------------------------  
//   $RCSfile: polstar.sci,v $
//  $Revision: 1.1 $
//      $Date: 2002/09/10 15:15:36 $
//  Copyright: IIF-LMB $Author: poluru $
//
//-----------------------------------------------------------------------
//  $Log: polstar.sci,v $
//  Revision 1.1  2002/09/10 15:15:36  poluru
//  "macros" directory structure is created
//
//-----------------------------------------------------------------------

  
  [out, in] = argn(0);
  if in ~=3,
    error('wrong number of input arguments.');
  end;
  
  // since origin is the center of the star so let us take the
  // first outer edge be on the x axis i.e P1= [ R; 0] 
  P = [R;0];
  
  // the angle to be rotated to reach the next point is: a=(2*%pi)/n
  a = (2*%pi)/n;
  
  
  // first inner edge is to be rotated at an angle a1=(%pi/n) from the first outer edge
  q = [r ; 0]; a1=%pi/n ;
  p = [cos(a1), sin(-a1); sin(a1), cos(a1)] * q;
  
  // finding all the outer and inner edges of the star in anti-clack wise direction
  P1 = P; p1 = p; 
  c = cos((1:n-1)*a);
  s = sin((1:n-1)*a);
  
  P1 = [P1, [P(1),P(2); P(2),-P(1)] * [c;-s] ] ;
  p1 = [p1, [p(1),p(2); p(2),-p(1)] * [c;-s] ] ;
  
  res = [matrix( [P1(1,:)', p1(1,:)']' ,1, 2*n);...
	 matrix( [P1(2,:)', p1(2,:)']' ,1, 2*n) ] ;
  
endfunction

